pub struct ApeFileInfo {Show 16 fields
pub descriptor: ApeDescriptor,
pub header: ApeHeader,
pub seek_table: Vec<u64>,
pub junk_header_bytes: u32,
pub wav_header_data: Vec<u8>,
pub total_blocks: i64,
pub block_align: u16,
pub bytes_per_sample: u16,
pub wav_data_bytes: i64,
pub length_ms: i64,
pub average_bitrate: i64,
pub decompressed_bitrate: i64,
pub seek_table_elements: i32,
pub ape_frame_data_bytes: u64,
pub terminating_data_bytes: u32,
pub file_bytes: u64,
}Expand description
All parsed and derived information about an APE file.
Fields
descriptor: ApeDescriptorheader: ApeHeaderseek_table: Vec<u64>junk_header_bytes: u32wav_header_data: Vec<u8>total_blocks: i64block_align: u16bytes_per_sample: u16wav_data_bytes: i64length_ms: i64average_bitrate: i64decompressed_bitrate: i64seek_table_elements: i32ape_frame_data_bytes: u64terminating_data_bytes: u32file_bytes: u64Implementations
Sourceimpl ApeFileInfo
impl ApeFileInfo
Sourcepub fn frame_block_count(&self, frame_idx: u32) -> u32
pub fn frame_block_count(&self, frame_idx: u32) -> u32
Returns the number of audio blocks in the given frame.
All frames except the last have blocks_per_frame blocks; the last
frame has final_frame_blocks.
Sourcepub fn frame_byte_count(&self, frame_idx: u32) -> u64
pub fn frame_byte_count(&self, frame_idx: u32) -> u64
Returns the compressed byte count for the given frame.
For non-final frames this is the difference between consecutive seek table entries. For the final frame it is the distance from its seek position to the end of the compressed data region.